==> haskell-attoparsec-0.14.4-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-72GG2lUmuC3GOdouXlk6Zr-attoparsec-internal

key:
    attoparsec-0.14.4-72GG2lUmuC3GOdouXlk6Zr-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  cef7e229408f617c1c0c9ce79e18153d
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-72GG2lUmuC3GOdouXlk6Zr-attoparsec-internal

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM
key:                  attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  537430d423b960ac2c51492cc600ac4e
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM
depends:
    array-0.5.4.0
    attoparsec-0.14.4-72GG2lUmuC3GOdouXlk6Zr-attoparsec-internal
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1 scientific-0.3.7.0-LbVWmnmXBYJ1OlsceRex9A text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.14.4-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-1UBjcBX5UJ2KOLwz3gunoW-attoparsec-internal

key:
    attoparsec-0.14.4-1UBjcBX5UJ2KOLwz3gunoW-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  2b255a4f41b170045586b25f86a00910
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-1UBjcBX5UJ2KOLwz3gunoW-attoparsec-internal

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu
key:                  attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  9b85f01a6c48cf469caca30517e7fe12
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu
depends:
    array-0.5.4.0
    attoparsec-0.14.4-1UBjcBX5UJ2KOLwz3gunoW-attoparsec-internal
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1 scientific-0.3.7.0-6O6FbUTzbTcBhAh2dckDIt text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
